@@ -6,7 +6,7 @@ import ntpath
 import os.path
 import posixpath
 import re
-from pathlib import Path
+from pathlib import Path, PurePath
 from typing import List, Optional, Pattern, Tuple
 
 from ._base import AbstractSanitizer, AbstractValidator, BaseFile, BaseValidator
@@ -75,7 +75,7 @@ class FilePathSanitizer(AbstractSanitizer):
             validate_pathtype(value, allow_whitespaces=not self._is_windows(include_universal=True))
         except ValidationError as e:
             if e.reason == ErrorReason.NULL_NAME:
-                if isinstance(value, Path):
+                if isinstance(value, PurePath):
                     raise
 
                 return self._null_value_handler(e)
@@ -117,7 +117,7 @@ class FilePathSanitizer(AbstractSanitizer):
         if self._validate_after_sanitize:
             self._validator.validate(sanitized_path)
 
-        if isinstance(value, Path):
+        if isinstance(value, PurePath):
             return Path(sanitized_path)
 
         return sanitized_path
@@ -303,16 +303,16 @@ def validate_filepath(
     """Verifying whether the ``file_path`` is a valid file path or not.
 
     Args:
-        file_path:
-            File path to validate.
-        platform:
+        file_path (PathType):
+            File path to be validated.
+        platform (Optional[PlatformType], optional):
             Target platform name of the file path.
 
             .. include:: platform.txt
-        min_len:
+        min_len (int, optional):
             Minimum byte length of the ``file_path``. The value must be greater or equal to one.
             Defaults to ``1``.
-        max_len:
+        max_len (Optional[int], optional):
             Maximum byte length of the ``file_path``. If the value is |None| or minus,
             automatically determined by the ``platform``:
 
@@ -320,10 +320,10 @@ def validate_filepath(
                 - ``macOS``: 1024
                 - ``Windows``: 260
                 - ``universal``: 260
-        fs_encoding:
+        fs_encoding (Optional[str], optional):
             Filesystem encoding that used to calculate the byte length of the file path.
             If |None|, get the value from the execution environment.
-        check_reserved:
+        check_reserved (bool, optional):
             If |True|, check reserved names of the ``platform``.
 
     Raises:
