@@ -7,7 +7,7 @@ import random
 import sys
 from collections import OrderedDict
 from itertools import chain, product
-from pathlib import Path
+from pathlib import Path, PurePosixPath, PureWindowsPath
 
 import pytest
 from allpairspy import AllPairs
@@ -288,6 +288,21 @@ class Test_validate_filename:
         assert e.value.reason == ErrorReason.INVALID_CHARACTER
         assert not is_valid_filename(value, platform=platform)
 
+    @pytest.mark.parametrize(
+        ["value", "platform"],
+        [
+            ["a/b", Platform.UNIVERSAL],
+            ["a*b", Platform.WINDOWS],
+            [PurePosixPath("a/b"), Platform.UNIVERSAL],
+            [PureWindowsPath("a/b"), Platform.WINDOWS],
+        ],
+    )
+    def test_exception_invalid_char_specific_target_platform(self, value, platform):
+        with pytest.raises(ValidationError) as e:
+            validate_filename(value, platform)
+        assert e.value.reason == ErrorReason.INVALID_CHARACTER
+        assert e.value.platform == platform
+
     @pytest.mark.parametrize(
         ["value", "platform"],
         [
@@ -640,7 +655,7 @@ class Test_sanitize_filename:
             "replacement_text": "",
             "validate_after_sanitize": False,
         }
-        print("'{}'".format(sanitize_filename(value, **kwargs)), file=sys.stderr)
+        print(f"'{sanitize_filename(value, **kwargs)}'", file=sys.stderr)
         kwargs["validate_after_sanitize"] = True
 
         with pytest.raises(ValidationError) as e:
